
# Type: cell line to disease or phenotypic feature association_subject




URI: [biolink:cell_line_to_disease_or_phenotypic_feature_association_subject](https://w3id.org/biolink/vocab/cell_line_to_disease_or_phenotypic_feature_association_subject)


## Domain and Range

[CellLineToDiseaseOrPhenotypicFeatureAssociation](CellLineToDiseaseOrPhenotypicFeatureAssociation.md) ->  <sub>REQ</sub> [DiseaseOrPhenotypicFeature](DiseaseOrPhenotypicFeature.md)

## Parents

 *  is_a: [subject](subject.md)

## Children


## Used by

 * [CellLineToDiseaseOrPhenotypicFeatureAssociation](CellLineToDiseaseOrPhenotypicFeatureAssociation.md)
